//+------------------------------------------------------------------+
//|                                      Indraws Volume Analysis.mq4 |
//+------------------------------------------------------------------+

#property copyright "Copyright  2007, Ryan Klefas"
#property link      "http://www.metaquotes.com"

#property indicator_separate_window
#property indicator_buffers 4
#property indicator_color1 DodgerBlue
#property indicator_color2 Red
#property indicator_color3 Lime
#property indicator_color4 Orange


double directionUpBuffer[];
double directionDownBuffer[];
double SlowCrossUp[];
double SlowCrossDown[];
double sumBufferu[];
double sumBufferd[];
double Med_Buffer[];
double Slow_Buffer[];

extern int    SwingPoint_Periods = 50;
extern bool   Backtesting        = false;
extern bool   ShowArrows         = true;

extern bool   alertsOn         = true;
extern bool   alertsOnCurrent  = true;
extern bool   alertsMessage    = true;
extern bool   alertsSound      = false;
extern bool   alertsNotify     = true;
extern bool   alertsEmail      = true;
extern string soundFile        = "alert2.wav"; 


int accumVol=0;
int candleCount=0;
double referenceLevel=0;
double refDiff=0;

int reset=-1;


//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   IndicatorBuffers(8);
   SetIndexStyle(0, DRAW_ARROW);
   SetIndexArrow(0, 233);
   SetIndexBuffer(0, directionUpBuffer);
   SetIndexStyle(1, DRAW_ARROW);
   SetIndexArrow(1, 234);
   SetIndexBuffer(1, directionDownBuffer);
   
   SetIndexStyle(2,DRAW_HISTOGRAM);
   SetIndexBuffer(2,sumBufferu);
   SetIndexStyle(3,DRAW_HISTOGRAM);
   SetIndexBuffer(3,sumBufferd);
   SetIndexBuffer(4,Med_Buffer);   
   SetIndexBuffer(5,Slow_Buffer);
   SetIndexBuffer(6, SlowCrossUp);
   SetIndexBuffer(7, SlowCrossDown);

//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//---- 
   Comment(" ");
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
double trend[];
int start() 
{

//+------------------------------------------------------------------+

   int i, r, limiter;

   int counted_bars=IndicatorCounted();
   if(counted_bars<0) return(-1);
   if(counted_bars>0) counted_bars--;

   int limit=Bars-counted_bars;
      if (ArraySize(trend)!=Bars) ArrayResize(trend,Bars);

   
   // Backtesting selection is to save the computer some processing time
   // Useful for more intensive indicators 
   // Enabled by default
   
   
   if (Backtesting)  
   {
      limiter = limit; 
      Comment("Backtesting Mode Enabled");
   }
   else              
   {
      limiter = 1000;
   }
      
      
      
   
   for(i = limiter, r=Bars-i-1; i > 0; i--,r++) 
   {
      trend[r] = trend[r-1];
      sumBufferu[i] = EMPTY_VALUE;
      sumBufferd[i] = EMPTY_VALUE;
      if (highPoint(i)) 
      {
         if (ShowArrows)
            directionDownBuffer[i] = accumVol;
            trend[r] = -1;
         accumVol=0;
         candleCount=reset;
         referenceLevel=High[i];
      }
      
         
      if (lowPoint(i)) 
      {
         if (ShowArrows)
            directionUpBuffer[i] = accumVol;
            trend[r] =  1;
            
         accumVol=0;
         candleCount=reset;
         referenceLevel=Low[i];
      }

         
         refDiff=referenceLevel-Close[i];
         accumVol+=Volume[i];
         candleCount++;
         if (trend[r] == 1)
               sumBufferu[i]=accumVol;
         else  sumBufferd[i]=accumVol;
         Slow_Buffer[i]=refDiff;
         Med_Buffer[i]=referenceLevel;
         

   }
   
   //
   //
   //
   //
   //
   
   if (alertsOn)
   {
      if (alertsOnCurrent)
         int whichBar = 0;
      else   whichBar = 1;
     
      //
      //
      //
      //
      //
     
      if (sumBufferu[whichBar] != EMPTY_VALUE && sumBufferd[whichBar+1] == EMPTY_VALUE) doAlert("Buy");
      if (sumBufferd[whichBar] != EMPTY_VALUE && sumBufferu[whichBar+1] == EMPTY_VALUE) doAlert("Sell");
  }
return(0);
}

//+------------------------------------------------------------------+
//| indicator functions                                              |
//+------------------------------------------------------------------+

double swingPoint(int shift)
{
   double val = iCustom(NULL, 0, "Swing_Point", SwingPoint_Periods, 0, shift);
   
   if (val < 99999999)     return (val);
   else                    return (-10);
}

//+------------------------------------------------------------------+

bool highPoint(int shift)
{  return (High[shift]==swingPoint(shift));  }

//+------------------------------------------------------------------+

bool lowPoint(int shift)
{  return (Low[shift]==swingPoint(shift));  }

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," Indraws Volume Analysis ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(StringConcatenate(Symbol(), Period() ," Indraws Volume Analysis " +" "+message));
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," Indraws Volume Analysis "),message);
             if (alertsSound)   PlaySound(soundFile);
      }
}

